@@ -12,7 +12,9 @@ from Cheetah.Template import Template
 from jsonstore import EntryManager
 
 
-def make_app(global_conf, dsn, templates,
+def make_app(global_conf, store, templates,
+        cache='simple://',
+        index='index.db',
         title='Test Webskine installation',
         entries=10,
         user='test',
@@ -22,13 +24,16 @@ def make_app(global_conf, dsn, templates,
 
     Configuration should be like this::
 
-        [app:weblob]
+        [app:webskine]
         use = egg:webskine
-        title = Weblog title
-        dsn = protocol://location 
+        title = Test Webskine installation
+        store = sqlite:///%(here)s/entries.db
+        cache = simple://
+        index = %(here)s/index.db
+        templates = %(here)s/templates/
         entries = 10
-        user = username
-        password = *******
+        user = test
+        password = test
     """
     from paste.auth.digest import digest_password, AuthDigestHandler
 
@@ -36,8 +41,9 @@ def make_app(global_conf, dsn, templates,
     from jsonstore import JSONStore
 
     # Apps we're using.
-    webskine = Webskine(dsn, templates, title, entries)
-    jsonstore = JSONStore(dsn) 
+    conf = {'store': store, 'cache': cache, 'index': index}
+    jsonstore = JSONStore(**conf)
+    webskine = Webskine(jsonstore.em, templates, title, entries)
 
     # Add authentication to the JSON store.
     def authfunc(environ, realm, username):
@@ -53,20 +59,20 @@ def make_app(global_conf, dsn, templates,
 
 
 class Webskine(object):
-    def __init__(self, dsn, templates, title, entries):
+    def __init__(self, em, templates, title, entries):
         self.templates = templates
         self.title = title
         self.entries = entries
 
         # Get entry manager.
-        self.em = EntryManager(dsn)
+        self.em = em
 
     def __call__(self, environ, start_response):
         path_info = environ.get('PATH_INFO', '/')
 
         # Parse request.
         dispatchers = [ ('/atom', lambda d: self._atom(**d)),
-                        ('/(?P<id>\d+)?', lambda d: self._entry(**d)), ]
+                        ('/(?P<id>.+)?', lambda d: self._entry(**d)), ]
         for regexp, func in dispatchers:
             p = re.compile(regexp)
             m = p.match(path_info)
@@ -91,7 +97,7 @@ class Webskine(object):
             title = self.title
         else:
             try:
-                entry = self.em.search(__id__=id)
+                entry = self.em.search(__id__=str(id))[0]
                 entries = [entry]
                 title = entry['title']
             except KeyError:
